@@ -22,7 +22,7 @@
 #' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>
 #' @examples
 #' set.seed(22)
-#' rows <- 300
+#' rows <- 200
 #' x1 <- rbinom(rows, 1, 0.5)
 #' x2 <- runif(rows, 0, 1)
 #' X <- cbind(x1,x2)
@@ -35,14 +35,14 @@
 #' #                    #
 #' ######################
 #'
-#' t_lambda <- 1
+#' t_lambda <- -1
 #' error <- rglg(rows, 0, 1, t_lambda)
 #' y1 <- error
 #' y1 <- X %*%t_beta + t_sigma*error
 #' data.example <- data.frame(y1,X)
-#' data.example <- data.frame(y1)
 #' fit <- glg(y1 ~ x1 + x2 - 1, data=data.example)
-#' logLik(fit) # -449.47  # Time: 14 milliseconds
+#' fit$condition
+#' logLik(fit)
 #' summary(fit)
 #' deviance_residuals(fit)
 #' #############################
@@ -73,7 +73,7 @@
 #' @importFrom Rcpp sourceCpp
 #' @export glg
 
-glg = function(formula, data, shape=-0.75, Tolerance=5e-05, Maxiter=1000, format='complete', envelope= FALSE) {
+glg = function(formula, data, shape=0.75, Tolerance=5e-05, Maxiter=1000, format='complete', envelope= FALSE) {
     if (missingArg(formula)) {
         stop("The formula argument is missing.")
     }
@@ -92,195 +92,128 @@ glg = function(formula, data, shape=-0.75, Tolerance=5e-05, Maxiter=1000, format
     p1 <- p + 1
     p2 <- p + 2
     n <- nrow(X)
-
     # Initial values
-
     fit0 <- .lm.fit(X,y)
     beta0 <- coef(fit0)
     ########################################################
-    frac <- 0.1
     s_fit0 <-  sort(fit0[[3]])
     breaks <- round(n*c(0.05,0.95))
-    res_sam <- s_fit0[seq(breaks[1],breaks[2],length=10)]
-    sigma0 <- sqrt(sum((n*frac)*(res_sam^2))/(n-p))
-
+    res_sam <- s_fit0[ seq(breaks[1],breaks[2],length=10)]
+    sigma0 <- sqrt(sum((n*0.1)*(res_sam^2))/(n-p))
     ########################################################
     med <- median(y)
     mean <- mean(y)
     skew_val <- (mean - med)/med
-    if(skew_val > 0.05) lambda0 <- shape
-    else if(skew_val > 0.025) lambda0 <- -0.25
-    else if(skew_val > - 0.055) lambda0 <- 0.25
-    else lambda0 <- -shape
+    lambda0 <- shape
 
+    if(skew_val > 0.05){
+       lambda0 <- shape
+    }else if(skew_val > 0.025){
+       lambda0 <- -0.25
+    }else if(skew_val > - 0.055){
+       lambda0 <- 0.25
+    }else{
+      lambda0 <- -shape
+    }
     ########################################################
     # Some fixed matrices
     One <- matrix(1, n, 1)
     I <- diag(1, n)
-
-    ## Defining the components of the FSIM
-
     t_X <- t(X)
     t_XX <- t_X %*% X
-    I_11 <- function(sigm) {
-      return ((1/(sigm^2)) * t_XX)
-    }
-
     t_XOne <- t_X %*% One
-    I_12 <- function(sigm, lambd) {
-        return((1/(sigm^2)) * u_lambda(lambd) * t_XOne)
-    }
-
-    I_13 <- function(sigm, lambd) {
-        return((-1/(sigm * lambd)) * u_lambda(lambd) * t_XOne)
-    }
-
-    I_33 <- function(sigm, lambd) {
-        return((n/(lambd^2)) * K_1(lambd))
-    }
-
+    # Fisher Matrix
     I_theta <- function(sigm,lambd) {
-        output <- cbind(I_11(sigm),I_12(sigm,lambd),I_13(sigm,lambd))
-        output <- rbind(output,c(output[1:p,p1],I_22(n,sigm,lambd),I_23(n,sigm,lambd)))
-        output <- rbind(output,c(output[1:p,p2],output[p1,p2],I_33(sigm,lambd)))
-        return(output)
+      inv_sigm <- 1/sigm
+      inv_sigm2 <- inv_sigm^2
+      inv_lamb <- 1/lambd
+      inv_lamb2 <- inv_lamb^2
+      output <- cbind(inv_sigm2*t_XX, inv_sigm2*u_lambda(lambd)*t_XOne, -inv_sigm * inv_lamb*u_lambda(lambd)*t_XOne)
+      output <- rbind(output, c(output[1:p, p1], I_22(n,sigm,lambd), I_23(n, sigm, lambd)))
+      output <- rbind(output, c(output[1:p, p2], output[p1, p2], n*inv_lamb2*K_1(lambd)))
+      return(output)
     }
-
     ### Defining mu function
-
     mu <- function(bet) {
         return(X %*% bet)
     }
-
     ### First step: The residuals
-
     eps <- function(bet, sigm) {
         return( (y - mu(bet))/sigm)
     }
-
     ### Second step: The matrix D
-
     D <- function(epsilon, lambd) {
         return(diag(as.vector(exp(lambd * epsilon))))
     }
-
     ### Third step: The matrix W
-
     W <- function(bet, sigm, lambd) {
         return(I - D(eps(bet, sigm), lambd))
     }
-
-    ## Final step: Score functions
-
-    U_beta <- function(bet, sigm, lambd) {
-        return((-1/(lambd * sigm)) * t_X %*% (W(bet, sigm, lambd) %*%One))
-    }
-
     t_One <- t(One)
-    U_sigma <- function(bet, sigm, lambd) {
-        return(-(1/sigm) * n - (1/(lambd * sigm)) * t_One %*% (W(bet,sigm, lambd) %*% eps(bet, sigm)))
-    }
-
-    U_lambda <- function(bet, sigm, lambd) {
-        invlamb <- 1/lambd
-        invlamb2 <- invlamb^2
-        eta_lambd <- (invlamb) * (1 + 2 * (invlamb2) * (digamma(invlamb2) + 2 * log(abs(lambd)) - 1))
-        Ds <- D(eps(bet, sigm), lambd)
-        epsilons <- eps(bet, sigm)
-        t_OneDs <- t_One %*% Ds
-        return(n * eta_lambd - (invlamb2) * t_One %*% epsilons + (2 * invlamb*invlamb2) * t_OneDs %*% One - (invlamb2) * t_OneDs %*% epsilons)
-    }
-
     U_theta <- function(bet, sigm, lambd) {
-        return(c(U_beta(bet, sigm, lambd),U_sigma(bet, sigm, lambd),U_lambda(bet, sigm, lambd)))
+      inv_sigm <- 1/sigm
+      inv_sigm2 <- inv_sigm^2
+      inv_lamb <- 1/lambd
+      inv_lamb2 <- inv_lamb^2
+      W <- W(bet, sigm, lambd)
+      epsilons <- eps(bet, sigm)
+      eta_lambd <- inv_lamb * (1 + 2 * inv_lamb2 * (digamma(inv_lamb2) + 2 * log(abs(lambd)) - 1))
+      Ds <- D(eps(bet, sigm), lambd)
+      return(
+             c(-inv_lamb*inv_sigm* t_X %*% (W %*% One),
+               -inv_sigm*n - inv_lamb*inv_sigm * t_One %*% (W %*% epsilons),
+              n*eta_lambd - inv_lamb2 * t_One %*% ( epsilons  + Ds %*% (epsilons - 2*inv_lamb))))
     }
-
+################################################################################################################################
     ## LOG-LIKELIHOOD
 
     loglikglg <- function(bet, sigm, lambd) {
         epsilon <- eps(bet, sigm)
         invlamb <- 1/lambd
-        return(n * log(c_l(lambd)/sigm) + (invlamb) * t_One %*% epsilon - (invlamb^2) * t_One %*% (D(epsilon, lambd) %*% One))
-        #return(n * (lc_l(lambd) - log(sigm)) + (invlamb) * t_One %*% epsilon - (invlamb^2) * t_One %*% (D(epsilon, lambd) %*% One))
+        return(n * log(c_l(lambd)/sigm) + invlamb * t_One %*% (epsilon - invlamb * (D(epsilon, lambd) %*% One)))
     }
-
-    ## THE ESTIMATES
-
+################################################################################################################################
     newpar <- function(bet, sigm, lambd) {
-        output <- matrix(0, p2, 2)
-        output[, 1] <- c(bet,sigm,lambd)
-        new <- output[, 1]
-        output[, 2] <- output[, 1] + solve(I_theta(sigm, lambd)) %*% U_theta(bet, sigm, lambd)
-        M = 2
-        while (output[p1, 2] < 0 & M < Maxiter) {
-            output[, 2] = 0.8 * output[, 2] + 0.2 * output[, 1]
-            M = M + 1
-        }
-        llglg = loglikglg(output[1:p, 2], output[p1, 2], output[p2,2])
-        condition = llglg - loglikglg(output[1:p, 1], output[p1, 1], output[p2, 1])
-        if (condition > 0) {
-            new = output[, 2]
-        }
-        M = 2
-        while (condition < 0 & M < Maxiter) {
-            output[, 2] = 0.8 * output[, 2] + 0.2 * output[, 1]
-            condition = loglikglg(output[1:p, 2], output[p1, 2], output[p2, 2]) - loglikglg(output[1:p, 1], output[p1, 1], output[p2, 1])
-            if (condition > 0) {
-                new = output[, 2]
-            }
-            M = M + 1
-        }
-        return(new)
+      scores <- U_theta(bet, sigm, lambd)
+      I <- I_theta(sigm, lambd)
+      ini <- c(bet,sigm,lambd)
+      dir <-  solve(I) %*% scores
+      llglg_ini <- loglikglg(bet, sigm, lambd)
+      condition <- -1
+      M <- 0
+      while (condition < 0 & M <= 10) {
+          new <- ini + (0.8**M)*dir
+          llglg_new <- loglikglg(new[1:p], new[p1], new[p2])
+          condition <- llglg_new - llglg_ini
+          M <- M + 1
+
+      }
+      return(new)
     }
-
-    ## THE MAIN FUNCTION
-
-    conv <- FALSE
-    condition <- 1
-    l <- 1
-
-    optimum <- function(bet, sigm, lambd) {
-        new = matrix(0, p2, Maxiter)
-        new[, 1] = newpar(bet, sigm, lambd)
-        ouput = new[, 1]
-        new[, 2] = newpar(new[1:p, 1], new[p1, 1], new[p2, 1])
-        l = 2
-        llglg = loglikglg(new[1:p, l], new[p1, l], new[p2, l])
-        condition = llglg - loglikglg(new[1:p, 1], new[p1, 1], new[p2, 1])
-        if (condition > 0) {
-            output = new[, l]
-        }
-        while (condition > Tolerance & l < Maxiter) {
-            l = l + 1
-            new[, l] = newpar(new[1:p, (l - 1)], new[p1, (l - 1)], new[p2, (l - 1)])
-            llglg = loglikglg(new[1:p, l], new[p1, l], new[p2,l])
-            condition = llglg - loglikglg(output[1:p], output[p1], output[p2])
-
-            if (condition > 0) {
-                output = new[, l]
-            }
-        }
-        if (condition < Tolerance & l < Maxiter) {
-            return(list(est = output, loglik = llglg, cond = condition, conv = TRUE, iter = l))
-        }
-        if (l >= Maxiter | scores > 0.05) {
-            conv = FALSE
-            return(list(conv = conv))
-            stop("")
+    optimum <- function(bet, sigm, lambd){
+      fin <- c(bet,sigm,lambd)
+      condition <- 1
+      l <- 1
+      while (condition > Tolerance & l <= Maxiter){
+        temp <- newpar(fin[1:p], fin[p1], fin[p2])
+        llglg_temp <- loglikglg(temp[1:p], temp[p1], temp[p2])
+        llglg_fin <- loglikglg(fin[1:p], fin[p1], fin[p2])
+        condition <- llglg_temp - llglg_fin
+        if (condition > 0){
+          fin <- temp
         }
+        l <- l + 1
+      }
+      if (condition < Tolerance) {
+        return(list(est = fin, loglik = llglg_fin, cond = condition, conv = TRUE, iter = l))
+      }
+      else{
+        print("The optimization process was not successful.")
+        return(list(conv = FALSE))
+        stop("")
+      }
     }
-
     output <- optimum(beta0, sigma0, lambda0)
-
-    if (abs(output$est[p2]) < 0.2) {
-        output <- optimum(beta0, sigma0, -lambda0)
-    }
-
-    if (output$conv == FALSE) {
-        print("The optimization was not successful.")
-        return(0)
-    }
-
     if (format == 'simple')
        {
         if(envelope==TRUE){
@@ -304,9 +237,6 @@ glg = function(formula, data, shape=-0.75, Tolerance=5e-05, Maxiter=1000, format
         aic <- -2 * llglg + 2 * p2
         bic <- -2 * llglg + log(n) * p2
         covar <- I_theta(sigma, lambda)
-        ste <- sqrt(diag(solve(covar)))
-        zs <- output$est/ste
-        pval <- 1 - (pnorm(abs(zs)) - pnorm(-abs(zs)))
         mu_est <- X %*% mus
         ordresidual <- eps(mus, sigma)
         sgn <- sign(y - mu_est)
@@ -317,8 +247,6 @@ glg = function(formula, data, shape=-0.75, Tolerance=5e-05, Maxiter=1000, format
         part2 <- (sigma*ilambda) * (digamma(ilambda2) - log(ilambda2))
         y_est <- mu_est + part2
         scores <- U_theta(mus, sigma, lambda)
-        delta <- 1.96 * ste
-        inter <- cbind(output$est - delta, output$est + delta)
         output <- list(formula = formula,
                        size = n,
                        mu = mus,
@@ -335,10 +263,6 @@ glg = function(formula, data, shape=-0.75, Tolerance=5e-05, Maxiter=1000, format
                        deviance = devian,
                        rdev = dev,
                        Itheta = covar,
-                       st_error = ste,
-                       z_values = zs,
-                       p.values = pval,
-                       interval = inter,
                        convergence = output$conv,
                        condition = output$cond,
                        iterations = output$iter,
