@@ -1,6 +1,6 @@
 #' Quantile Residuals for a Generalized Log-gamma Regression Model
 #'
-#' \code{quantile_residuals} is used to generate quantile residuals for a generalized log-gamma regression model.
+#' \code{quantile_sglg} is used to generate quantile residuals for a generalized log-gamma regression model.
 #' @param fit is an object sglg. This object is returned from the call to glg(), sglg(), survglg() or ssurvglg().
 #' @references Carlos Alberto Cardozo Delgado, Semi-parametric generalized log-gamma regression models. Ph. D. thesis. Sao Paulo University.
 #' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>
@@ -15,7 +15,7 @@
 #'fit_0$mu
 #'fit_0$sigma
 #'fit_0$lambda
-#'quantile_residuals(fit_0)
+#'quantile_sglg(fit_0)
 #'# Example 2
 #'n <- 500
 #'set.seed(6)
@@ -28,12 +28,12 @@
 #'fit_1$mu
 #'fit_1$sigma
 #'fit_1$lambda
-#'quantile_residuals(fit_1)
+#'quantile_sglg(fit_1)
 #'@import moments
 #'@import ggplot2
 #'@import gridExtra
-#'@export quantile_residuals
-quantile_residuals <- function(fit){
+#'@export quantile_sglg
+quantile_sglg <- function(fit){
 r_quantile <- quantile(as.numeric(qnorm( pglg(fit$y,location=fit$mu_est,scale=fit$sigma,shape=fit$lambda))),seq(0.02,0.98,by=0.01))
 cond_1 <- r_quantile == Inf
 if(sum(cond_1) > 0)
